# Reference

## Classes
### Public Classes
* [`dns`](#dns): Manage an ISC BIND nameserver
### Private Classes
* `dns::config`: Configure dns
* `dns::install`: Install dns service
* `dns::params`: Default parameters
* `dns::service`: Enable and start dns service
## Defined types
* [`dns::key`](#dnskey): Generate a new key for the dns
* [`dns::view`](#dnsview): Define new view for the dns
* [`dns::zone`](#dnszone): Define new zone for the dns
## Functions
* [`date`](#date): 
* [`get_in_addr_arpa`](#get_in_addr_arpa): 
## Classes

### dns

Manage an ISC BIND nameserver

* **See also**
dns::zone

dns::key



#### Parameters

The following parameters are available in the `dns` class.

##### `namedconf_path`

Data type: `Stdlib::Absolutepath`

Path of the named config

Default value: $dns::params::namedconf_path

##### `dnsdir`

Data type: `Stdlib::Absolutepath`

Directory holding the named configs

Default value: $dns::params::dnsdir

##### `dns_server_package`

Data type: `String`

Name of the package to install

Default value: $dns::params::dns_server_package

##### `rndckeypath`

Data type: `Stdlib::Absolutepath`

Path of the RNDC key

Default value: $dns::params::rndckeypath

##### `optionspath`

Data type: `Stdlib::Absolutepath`

Path of the named options

Default value: $dns::params::optionspath

##### `publicviewpath`

Data type: `Stdlib::Absolutepath`

Path of the config file holding all the zones

Default value: $dns::params::publicviewpath

##### `vardir`

Data type: `Stdlib::Absolutepath`

Directory holding the variable or working files

Default value: $dns::params::vardir

##### `namedservicename`

Data type: `String`

Name of the service

Default value: $dns::params::namedservicename

##### `zonefilepath`

Data type: `Stdlib::Absolutepath`

Directory containing zone files

Default value: $dns::params::zonefilepath

##### `localzonepath`

Data type: `Variant[Enum['unmanaged'], Stdlib::Absolutepath]`

File holding local zones like RFC1912 or RFC1918 files.  The special value
'unmanaged' can be used if one plans to create custom RFC1912/RFC1918 zones
via dns, where the inclusion of package-shipped zone files is not desired.

Default value: $dns::params::localzonepath

##### `defaultzonepath`

Data type: `Variant[Enum['unmanaged'], Stdlib::Absolutepath]`

File holding some RFC1912 zone includes on systems like Debian.
The special value 'unmanaged' can be used if one plans to create custom
zones via dns, where the inclusion of package-shipped zone files is not
desired.

Default value: $dns::params::defaultzonepath

##### `forward`

Data type: `Optional[Enum['only', 'first']]`

The forward option

Default value: $dns::params::forward

##### `forwarders`

Data type: `Array[String]`

The forwarders option

Default value: $dns::params::forwarders

##### `listen_on_v6`

Data type: `Optional[Variant[String, Boolean]]`

The listen-on-v6 option

Default value: $dns::params::listen_on_v6

##### `recursion`

Data type: `Enum['yes', 'no']`

The recursion option

Default value: $dns::params::recursion

##### `allow_recursion`

Data type: `Array[String]`

The allow-recursion option

Default value: $dns::params::allow_recursion

##### `allow_query`

Data type: `Array[String]`

The allow-query option

Default value: $dns::params::allow_query

##### `empty_zones_enable`

Data type: `Enum[yes, no]`

The empty-zones-enable option

Default value: $dns::params::empty_zones_enable

##### `dns_notify`

Data type: `Optional[Enum['yes', 'no', 'explicit']]`

The notify option in named.conf

Default value: $dns::params::dns_notify

##### `dnssec_enable`

Data type: `Enum['yes', 'no']`

The dnssec-enable option

Default value: $dns::params::dnssec_enable

##### `dnssec_validation`

Data type: `Enum['yes', 'no', 'auto']`

The dnssec-validation option

Default value: $dns::params::dnssec_validation

##### `namedconf_template`

Data type: `String`

The template to be used for named.conf

Default value: $dns::params::namedconf_template

##### `acls`

Data type: `Hash[String, Array[String]]`

Specify a hash of ACLs. Each key is the name of a network, and its value is
an array of subnet strings.

Default value: $dns::params::acls

##### `optionsconf_template`

Data type: `String`

The template to be used for options.conf

Default value: $dns::params::optionsconf_template

##### `controls`

Data type: `Hash[String, Hash[String, Data]]`

Specify a hash of controls. Each key is the name of a network, and its
value is a hash containing 'port' => integer, 'keys' => array and
'allowed_addresses' => array

Default value: $dns::params::controls

##### `service_ensure`

Data type: `Variant[Enum['running', 'stopped'], Boolean]`

The ensure attribute on the service

Default value: $dns::params::service_ensure

##### `service_enable`

Data type: `Boolean`

Whether to enable the service (start at boot)

Default value: $dns::params::service_enable

##### `additional_options`

Data type: `Hash[String, Data]`

Additional options

Default value: $dns::params::additional_options

##### `additional_directives`

Data type: `Array[String]`

Additional directives. These are free form strings that allow for full
customization. Use with caution.

Default value: $dns::params::additional_directives

##### `enable_views`

Data type: `Boolean`

Flag to indicate bind views support. Will remove global zone configuration
like localzonepath inclusion.

Default value: $dns::params::enable_views

##### `zones`

Data type: `Hash[String, Hash]`

A hash of zones to be created. See dns::zone for options.

Default value: $dns::params::zones

##### `keys`

Data type: `Hash[String, Hash]`

A hash of keys to be created. See dns::key for options.

Default value: $dns::params::keys


## Defined types

### dns::key

Generate a new key for the dns


#### Parameters

The following parameters are available in the `dns::key` defined type.

##### `algorithm`

Data type: `String`

The algorithm used to generate the secret key

Default value: 'hmac-md5'

##### `filename`

Data type: `String`

The filename to store the key. This is placed in the key directory.

Default value: "${name}.key"

##### `secret`

Data type: `Optional[String]`

This is the secret to be place inside the keyfile, if left empty the key
will be generated

Default value: `undef`

##### `keydir`

Data type: `Stdlib::Absolutepath`

The directory to store the key in. Inherited from the main dns class by default.

Default value: $dns::dnsdir

##### `keysize`

Data type: `Integer`

The size of the key to generate. Only used when generating the key. It's
ignored if when a key is specified.

Default value: 512


### dns::view

Define new view for the dns


#### Parameters

The following parameters are available in the `dns::view` defined type.

##### `match_clients`

Data type: `Array[String]`



Default value: []

##### `match_destinations`

Data type: `Array[String]`



Default value: []

##### `match_recursive_only`

Data type: `Enum['yes','no']`



Default value: 'no'

##### `allow_transfer`

Data type: `Array[String]`



Default value: []

##### `allow_recursion`

Data type: `Array[String]`



Default value: []

##### `allow_query`

Data type: `Array[String]`



Default value: []

##### `allow_query_cache`

Data type: `Array[String]`



Default value: []

##### `also_notify`

Data type: `Array[String]`



Default value: []

##### `forwarders`

Data type: `Array[String]`



Default value: []

##### `forward`

Data type: `Enum['only','first']`



Default value: 'first'

##### `recursion`

Data type: `Enum['yes','no']`



Default value: 'yes'

##### `dnssec_enable`

Data type: `Enum['yes','no']`



Default value: 'yes'

##### `dnssec_validation`

Data type: `Enum['yes','no']`



Default value: 'yes'

##### `dns_notify`

Data type: `Enum['yes','no']`



Default value: 'yes'

##### `include_localzones`

Data type: `Boolean`



Default value: `true`

##### `include_defaultzones`

Data type: `Boolean`



Default value: `true`

##### `order`

Data type: `String`



Default value: '-'


### dns::zone

Define new zone for the dns


#### Parameters

The following parameters are available in the `dns::zone` defined type.

##### `manage_file`

Data type: `Boolean`

Whether the manage the file resource. When true $manage_file_name is implied.

Default value: `true`

##### `manage_file_name`

Data type: `Boolean`

Whether to set the file parameter in the zone file.

Default value: `false`

##### `update_policy_rules`

Data type: `Hash[String, Hash[String, Data]]`

This can be used to specifiy additional update policy rules in the
following format
{ '<KEY_NAME' => {'matchtype' => '<VALUE>', 'tname' => '<VALUE>', 'rr' => 'VALUE' } }
Example {'foreman_key' => {'matchtype' => 'zonesub', 'rr' => 'ANY'}}
tname and rr are optional

Default value: {}

##### `target_views`

Data type: `Array[String]`



Default value: []

##### `zonetype`

Data type: `String`



Default value: 'master'

##### `soa`

Data type: `String`



Default value: $fqdn

##### `reverse`

Data type: `Boolean`



Default value: `false`

##### `ttl`

Data type: `String`



Default value: '10800'

##### `soaip`

Data type: `Stdlib::Compat::Ip_address`



Default value: $ipaddress

##### `refresh`

Data type: `Integer`



Default value: 86400

##### `update_retry`

Data type: `Integer`



Default value: 3600

##### `expire`

Data type: `Integer`



Default value: 604800

##### `negttl`

Data type: `Integer`



Default value: 3600

##### `serial`

Data type: `Integer`



Default value: 1

##### `masters`

Data type: `Array`



Default value: []

##### `allow_transfer`

Data type: `Array`



Default value: []

##### `allow_query`

Data type: `Array`



Default value: []

##### `also_notify`

Data type: `Array`



Default value: []

##### `zone`

Data type: `String`



Default value: $title

##### `contact`

Data type: `Optional[String]`



Default value: `undef`

##### `zonefilepath`

Data type: `Stdlib::Absolutepath`



Default value: $dns::zonefilepath

##### `filename`

Data type: `String`



Default value: "db.${title}"

##### `forward`

Data type: `Enum['first', 'only']`



Default value: 'first'

##### `forwarders`

Data type: `Array`



Default value: []

##### `dns_notify`

Data type: `Optional[Enum['yes', 'no', 'explicit']]`



Default value: `undef`


## Functions

### date
Type: Ruby 3.x API

The date class.

#### `date()`

Returns: `Any`

### get_in_addr_arpa
Type: Ruby 3.x API

The get_in_addr_arpa class.

#### `get_in_addr_arpa()`

Returns: `Any`

